@@ -15,16 +15,31 @@ remote <- function(spec) {
 
 # take a short-form remotes spec, parse that into a remote,
 # and generate a corresponding package record
-renv_remotes_resolve <- function(spec, latest = FALSE) {
+renv_remotes_resolve <- function(spec, latest = FALSE, infer = FALSE) {
 
   # check for already-resolved specs
   if (is.null(spec) || is.list(spec))
     return(spec)
 
+  # check for a package name prefix and remove it
+  regexps <- .standard_regexps()
+  pattern <- sprintf("^%s=", regexps$valid_package_name)
+  spec <- sub(pattern, "", spec)
+
   # remove a trailing slash
   # https://github.com/rstudio/renv/issues/1135
   spec <- gsub("/+$", "", spec, perl = TRUE)
 
+  # check if we should infer the package version
+  # from a locally-installed copy of the package
+  infer <-
+    infer &&
+    grepl(renv_regexps_package_name(), spec) &&
+    renv_package_installed(spec)
+
+  if (infer)
+    spec <- paste(spec, renv_package_version(spec), sep = "@")
+
   # check for archive URLs -- this is a bit hacky
   if (grepl("^(?:file|https?)://", spec)) {
     for (suffix in c(".zip", ".tar.gz", ".tgz", "/tarball"))
@@ -45,6 +60,25 @@ renv_remotes_resolve <- function(spec, latest = FALSE) {
       return(record)
   }
 
+  # check for explicit local remotes
+  if (grepl("^local::", spec)) {
+    spec <- substring(spec, 8L)
+    record <- catch(renv_remotes_resolve_path(spec))
+    if (!inherits(record, "error"))
+      return(record)
+  }
+
+  # check for requests to install local packages -- note that depending on how
+  # the R package was built / generated, it's possible that it might not adhere
+  # to the "typical" R package names, so we try to be a bit flexible here
+  ext <- "(?:\\.tar\\.gz|\\.tgz|\\.zip)$"
+  if (grepl(ext, spec, perl = TRUE)) {
+    pathlike <- tryCatch(file.exists(spec), condition = identity)
+    if (identical(pathlike, TRUE)) {
+      return(renv_remotes_resolve_path(spec))
+    }
+  }
+
   # define error handler (tag error with extra context when possible)
   error <- function(e) {
 
@@ -78,6 +112,12 @@ renv_remotes_resolve_impl <- function(spec, latest = FALSE) {
   if (isbioc)
     remote$type <- "bioc"
 
+  # treat HEAD refs as an implicit request to use the default branch
+  # of the associated remote repository
+  # https://github.com/rstudio/renv/issues/2040
+  if (identical(remote$ref, "HEAD"))
+    remote$ref <- NULL
+
   resolved <- switch(
     remote$type,
     bioc       = renv_remotes_resolve_bioc(remote),
@@ -99,9 +139,9 @@ renv_remotes_resolve_impl <- function(spec, latest = FALSE) {
 
 }
 
-renv_remotes_parse_impl <- function(spec, pattern, fields, perl = FALSE) {
+renv_remotes_parse_impl <- function(spec, pattern, fields) {
 
-  matches <- regexec(pattern, spec, perl = perl)
+  matches <- regexec(pattern, spec, perl = TRUE)
   strings <- regmatches(spec, matches)[[1]]
   if (empty(strings))
     stopf("'%s' is not a valid remote", spec)
@@ -137,10 +177,10 @@ renv_remotes_parse_remote <- function(spec) {
     "(?:([[:alpha:]][[:alnum:].]*[[:alnum:]])=)?",  # optional package name
     "(?:([^@:]+)(?:@([^:]+))?::)?",                 # optional prefix, providing type + host
     "([^/#@:]+)",                                   # a username
-    "(?:/([^@#:]+))?",                              # a repository (allow sub-repositories)
-    "(?::([^@#:]+))?",                              # optional subdirectory
-    "(?:#([^@#:]+))?",                              # optional hash (e.g. pull request)
-    "(?:@([^@#:]+))?",                              # optional ref (e.g. branch or commit)
+    "(?:[/]([^@#:]+))?",                            # a repository (allow sub-repositories)
+    "(?:[:]([^@#]+))?",                             # optional subdirectory
+    "(?:[#]([^@]+))?",                              # optional hash (e.g. pull request)
+    "(?:[@](.+))?",                                 # optional ref (e.g. branch or commit)
     "$"
   )
 
@@ -181,7 +221,7 @@ renv_remotes_parse_gitssh <- function(spec) {
     "subdir", "pull", "ref"
   )
 
-  remote <- renv_remotes_parse_impl(spec, pattern, fields, perl = TRUE)
+  remote <- renv_remotes_parse_impl(spec, pattern, fields)
   if (!nzchar(remote$repo))
     stopf("'%s' is not a valid remote", spec)
 
@@ -224,7 +264,7 @@ renv_remotes_parse_git <- function(spec) {
     "subdir", "pull", "ref"
   )
 
-  remote <- renv_remotes_parse_impl(spec, pattern, fields, perl = TRUE)
+  remote <- renv_remotes_parse_impl(spec, pattern, fields)
   if (!nzchar(remote$repo))
     stopf("'%s' is not a valid remote", spec)
 
@@ -252,7 +292,7 @@ renv_remotes_parse_url <- function(spec) {
   )
 
   fields <- c("spec", "package", "type", "url", "protocol", "path", "subdir")
-  remote <- renv_remotes_parse_impl(spec, pattern, fields, perl = TRUE)
+  remote <- renv_remotes_parse_impl(spec, pattern, fields)
   if (!nzchar(remote$url))
     stopf("'%s' is not a valid remote", spec)
 
@@ -432,6 +472,7 @@ renv_remotes_resolve_repository <- function(remote, latest) {
   if (latest && is.null(version)) {
     remote <- renv_available_packages_latest(package)
     version <- remote$Version
+    repository <- remote$Repository
   }
 
   list(
@@ -479,8 +520,9 @@ renv_remotes_resolve_github_sha_ref <- function(host, user, repo, ref) {
   # build url for github commits endpoint
   fmt <- "%s/repos/%s/%s/commits/%s"
   origin <- renv_retrieve_origin(host)
-  ref <- ref %||% getOption("renv.github.default_branch", default = "master")
-  url <- sprintf(fmt, origin, user, repo, ref %||% "master")
+
+  ref <- ref %||% renv_remotes_resolve_github_ref(host, user, repo)
+  url <- sprintf(fmt, origin, user, repo, ref %||% "main")
 
   # prepare headers
   headers <- c(Accept = "application/vnd.github.sha")
@@ -541,7 +583,7 @@ renv_remotes_resolve_github_modules <- function(host, user, repo, subdir, sha) {
 
 }
 
-renv_remotes_resolve_github_description <- function(host, user, repo, subdir, sha) {
+renv_remotes_resolve_github_description <- function(url, host, user, repo, subdir, sha) {
 
   # form DESCRIPTION path
   subdir <- subdir %||% ""
@@ -558,7 +600,7 @@ renv_remotes_resolve_github_description <- function(host, user, repo, subdir, sh
   # add headers
   headers <- c(
     Accept = "application/vnd.github.raw",
-    renv_download_auth_github()
+    renv_download_auth_github(url)
   )
 
   # get the DESCRIPTION contents
@@ -590,7 +632,7 @@ renv_remotes_resolve_github_ref <- function(host, user, repo) {
     renv_remotes_resolve_github_ref_impl(host, user, repo),
     error = function(e) {
       warning(e)
-      getOption("renv.github.default_branch", default = "master")
+      getOption("renv.github.default_branch", default = "main")
     }
   )
 
@@ -612,7 +654,7 @@ renv_remotes_resolve_github_ref_impl <- function(host, user, repo) {
   json <- renv_json_read(jsonfile)
 
   # read default branch
-  json$default_branch %||% getOption("renv.github.default_branch", default = "master")
+  json$default_branch %||% getOption("renv.github.default_branch", default = "main")
 
 }
 
@@ -640,20 +682,20 @@ renv_remotes_resolve_github <- function(remote) {
   )
 
   # if an abbreviated sha was provided as the ref, expand it here
-  if (nzchar(ref) && startswith(sha, ref))
+  if (nzchar(ref) && startsWith(sha, ref))
     ref <- sha
 
   # check whether the repository has a .gitmodules file; if so, then we'll have
   # to use a plain 'git' client to retrieve the package
   modules <- renv_remotes_resolve_github_modules(host, user, repo, subdir, sha)
-  url <- if (modules) {
-    origin <- fsub("api.github.com", "github.com", renv_retrieve_origin(host))
-    parts <- c(origin, user, repo)
-    paste(parts, collapse = "/")
-  }
+
+  # construct full url
+  origin <- fsub("api.github.com", "github.com", renv_retrieve_origin(host))
+  parts <- c(origin, user, repo)
+  url <- paste(parts, collapse = "/")
 
   # read DESCRIPTION
-  desc <- renv_remotes_resolve_github_description(host, user, repo, subdir, sha)
+  desc <- renv_remotes_resolve_github_description(url, host, user, repo, subdir, sha)
 
   list(
     Package        = desc$Package,
@@ -787,17 +829,8 @@ renv_remotes_resolve_git_description <- function(record) {
 }
 
 renv_remotes_resolve_git_pull <- function(pr) {
-  # to be able to checkout PR 760:
-  # git fetch origin pull/760/head:pr-760
-  # or:
-  # git fetch origin pull/760/head:pull/760
-
-  # so format for ref is:
-  # pull/{ref_number}/head:pr-{ref_number}
-  fmt <- "pull/%s/head:pull/%s"
-
-  remote_ref <- sprintf(fmt, pr, pr)
-  remote_ref
+  fmt <- "pull/%1$s/head:pull/%1$s"
+  sprintf(fmt, pr)
 }
 
 renv_remotes_resolve_gitlab_ref <- function(host, user, repo) {
@@ -843,11 +876,11 @@ renv_remotes_resolve_gitlab <- function(remote) {
   host   <- remote$host %||% config$gitlab.host()
   user   <- remote$user
   repo   <- remote$repo
-  subdir <- remote$subdir %||% ""
+  subdir <- remote$subdir
 
   ref <- remote$ref %||% renv_remotes_resolve_gitlab_ref(host, user, repo)
 
-  parts <- c(if (nzchar(subdir)) subdir, "DESCRIPTION")
+  parts <- c(subdir, "DESCRIPTION")
   descpath <- URLencode(paste(parts, collapse = "/"), reserved = TRUE)
 
   # scope authentication
@@ -892,10 +925,7 @@ renv_remotes_resolve_gitlab <- function(remote) {
 
 renv_remotes_resolve_url <- function(url, quiet = FALSE) {
 
-  tempfile <- renv_scope_tempfile("renv-url-")
-  writeLines(url, con = tempfile)
-  hash <- tools::md5sum(tempfile)
-
+  hash <- md5(url)
   ext <- fileext(url, default = ".tar.gz")
   name <- paste(hash, ext, sep = "")
   path <- renv_paths_source("url", name)
