@@ -1,8 +1,4 @@
 
-# controls whether hashes are computed when computing a snapshot
-# can be scoped to FALSE when hashing is not necessary
-the$auto_snapshot_hash <- TRUE
-
 #' Record current state of the project library in the lockfile
 #'
 #' @description
@@ -114,7 +110,7 @@ the$auto_snapshot_hash <- TRUE
 #'   validation checks have failed?
 #'
 #' @param reprex Boolean; generate output appropriate for embedding the lockfile
-#'   as part of a [reprex](https://www.tidyverse.org/help/#reprex)?
+#'   as part of a [reprex](https://tidyverse.org/help/#reprex)?
 #'
 #' @return The generated lockfile, as an \R object (invisibly). Note that
 #'   this function is normally called for its side effects.
@@ -131,7 +127,7 @@ snapshot <- function(project  = NULL,
                      library  = NULL,
                      lockfile = paths$lockfile(project = project),
                      type     = settings$snapshot.type(project = project),
-                     dev      = FALSE,
+                     dev      = NULL,
                      repos    = getOption("repos"),
                      packages = NULL,
                      exclude  = NULL,
@@ -150,6 +146,10 @@ snapshot <- function(project  = NULL,
   renv_project_lock(project = project)
   renv_scope_verbose_if(prompt)
 
+  # use setting as default if dev not explicitly provided
+  if (is.null(dev))
+    dev <- settings$snapshot.dev(project = project)
+
   repos <- renv_repos_validate(repos)
   renv_scope_options(repos = repos)
 
@@ -727,7 +727,10 @@ renv_snapshot_description <- function(path = NULL, package = NULL) {
 
 renv_snapshot_description_impl <- function(dcf, path = NULL) {
 
-  version <- getOption("renv.lockfile.version", default = 2L)
+  version <-
+    getOption("renv.lockfile.version") %||%
+    Sys.getenv("RENV_LOCKFILE_VERSION", unset = 2L)
+
   if (version == 1L)
     renv_snapshot_description_impl_v1(dcf, path)
   else if (version == 2L)
@@ -754,7 +757,7 @@ renv_snapshot_description_impl_v1 <- function(dcf, path = NULL) {
   # if this is a standard remote for a bioconductor package,
   # remove the other remote fields
   bioc <-
-    !is.null(dcf[["biocViews"]]) &&
+    nzchar(dcf[["biocViews"]] %||% "") &&
     identical(dcf[["RemoteType"]], "standard")
 
   if (bioc) {
@@ -763,12 +766,10 @@ renv_snapshot_description_impl_v1 <- function(dcf, path = NULL) {
   }
 
   # generate a hash if we can
-  dcf[["Hash"]] <- if (the$auto_snapshot_hash) {
-    if (is.null(path))
-      renv_hash_record(dcf)
-    else
-      renv_hash_description(path)
-  }
+  dcf[["Hash"]] <- if (is.null(path))
+    renv_hash_record(dcf)
+  else
+    renv_hash_description(path)
 
   # generate a Requirements field -- primarily for use by 'pak'
   fields <- c("Depends", "Imports", "LinkingTo")
@@ -828,7 +829,7 @@ renv_snapshot_description_impl_v2 <- function(dcf, path) {
   # if this is a standard remote for a bioconductor package,
   # remove the other remote fields
   bioc <-
-    !is.null(dcf[["biocViews"]]) &&
+    nzchar(dcf[["biocViews"]] %||% "") &&
     identical(dcf[["RemoteType"]], "standard")
 
   if (bioc) {
@@ -884,8 +885,12 @@ renv_snapshot_description_source_custom <- function(dcf) {
     return(NULL)
 
   # if this package appears to be installed from Bioconductor, skip
-  biocviews <- dcf[["biocViews"]]
-  if (!is.null(biocviews))
+  if (nzchar(dcf[["biocViews"]] %||% ""))
+    return(NULL)
+
+  # if the declared repository appears to be a CRAN mirror, skip it
+  mirrors <- renv_cran_mirrors()
+  if (any(renv_repos_matches(remoterepos, mirrors)))
     return(NULL)
 
   # if this package appears to have been installed from a
@@ -895,11 +900,17 @@ renv_snapshot_description_source_custom <- function(dcf) {
   if (!is.null(repository) && repository %in% names(repos))
     return(NULL)
 
-  # check whether this repository is already in use;
-  # if so, we can skip declaring it
+  # check whether the declared repository matches one of the
+  # repositories that are currently in use; if so, skip it
+  #
+  # we explicitly ignore 'CRAN' as a repository name here, since older
+  # versions of renv may have erroneously marked packages installed from
+  # other package repositories as 'CRAN'
+  #
+  # https://github.com/rstudio/renv/issues/2104
   name <- dcf[["RemoteReposName"]]
-  declared <- if (is.null(name))
-    remoterepos %in% repos
+  declared <- if (is.null(name) || identical(name, "CRAN"))
+    renv_repos_matches(remoterepos, repos)
   else
     name %in% names(repos)
 
@@ -926,7 +937,7 @@ renv_snapshot_description_source <- function(dcf) {
 
   # packages from Bioconductor are normally tagged with a 'biocViews' entry;
   # use that to infer a Bioconductor source
-  if (!is.null(dcf[["biocViews"]]))
+  if (nzchar(dcf[["biocViews"]] %||% ""))
     return(list(Source = "Bioconductor"))
 
   # check for a declared repository
